# Installation | Установка

## Windows
```
pip install wiq
```

## Linux
```
pip3 install wiq
```

![изображение](https://imgur.com/yE4ZO5P.jpg)

# Information | Информация
```
ENG: The current version of wiq is 0.1.2
RU: Актуальная версия wiq 0.1.2

Доступные методы:
-- getBalance()
-- getServices()
-- createOrder()
-- getStatus()
-- getCancel()
-- getRefill()
```

## Дополнительная информация
```
Библиотека до сих пор находится в стадии разработки, 
поэтому смело пишите мне в тг @the_vox
```